@@ -33,6 +33,9 @@ struct strtag {
 #define ICONV_ERROR           ((iconv_t)-1)
 #define BUFSIZE               1024
 
+// ¸ʸʤɡiconvѴʤäʸ֤
+#define LIBDG_PLACEHOLDER '?'
+
 
 /*--- ץȥ ---*/
 
@@ -53,5 +56,8 @@ extern int   iseuc(unsigned char);
 extern void *dg_realloc(void *, size_t);
 extern char *str2code(char *, char *, char *);
 extern int   dg_str2code(char *, char **, char *, char *);
+// ¸ʸ֤褦ȤС
+extern char *str2code_replace(char *, char *, char *);
+extern int   dg_str2code_replace(char *, char **, char *, char *);
 
 #endif  /* _LIBDGSTR_H_ */
