@@ -309,6 +309,15 @@ mlfi_envfrom(SMFICTX *ctx, char **envfrom)
         return SMFIS_CONTINUE;
     }
 
+    /* invalid character check */
+    if (ismode_enc) {
+        ret = check_fromaddr(fromaddr, priv->mlfi_conf->cf_allowcharenvelopefrom);
+        if (ret != 0) {
+            log(INVALID_CHAR, fromaddr);
+            return SMFIS_REJECT;
+        }
+    }
+
      /* domain null check */
     fqdn = strchr(fromaddr, ATMARK);
     if (fqdn == NULL) {
@@ -692,6 +701,26 @@ mlfi_abort(SMFICTX *ctx)
     return SMFIS_CONTINUE;
 }
 
+/*
+ * check_fromaddr
+ */
+int
+check_fromaddr(char *addr, char *allowchar)
+{
+    if (allowchar ==  NULL) {
+        return 1;
+    }
+
+    char *p;
+
+    for (p = addr; *p != '\0'; p++) {
+        if (strchr(allowchar, *p) == NULL) {
+            return 1;
+        }
+    }
+    return 0;
+}
+
 /*
  * mlfi_cleanup
  * cleanup
