@@ -999,7 +999,7 @@ tmpl_tag_replace(char *tmp, struct mailzip mz, struct rcptinfo *other, char *sen
             log(ERR_CHARCODE_CONVERT, "tmpl_tag_replace");
             subject = strdup(NOT_ENC_SUBJECT);
 	    if (subject == NULL) {
-                log(ERR_MEMORY_ALLOCATE, "tmpl_tag_replace", "subject", strerror(errno));
+            log(ERR_MEMORY_ALLOCATE, "tmpl_tag_replace", "subject", strerror(errno));
 		return(ERROR);
 	    }
 	}
@@ -1119,20 +1119,23 @@ tmpl_tag_replace(char *tmp, struct mailzip mz, struct rcptinfo *other, char *sen
     if (tmp_dec == NULL) {
         log(ERR_MEMORY_ALLOCATE, "tmpl_tag_replace of decode_mime", 
             "tmp_dec", strerror(errno));
-	return(ERROR);
+        return(CONVERT_ERROR);
     }
 
     /* Repairing for encoded Subject by MIME encode(2014/05/14(wed)) */
     if (dg_str2code_replace(tmp_dec, &tmpl, STR_UTF8, STR_JIS) != 0) {
         log(ERR_CHARCODE_CONVERT, "tmpl_tag_replace");
-	free(tmpp);
+        free(tmpp);
         free(tmp_dec);
-	if (subject != NULL) {
-	    free(subject);
-	}
-	free(filename);
-	return(ERROR);
+
+        if (subject != NULL) {
+            free(subject);
+        }
+        free(filename);
+
+        return(CONVERT_ERROR);
     }
+
     /* Repairing for encoded Subject by MIME encode(2014/05/14(wed)) */
     free(tmp_dec);
 
@@ -1155,19 +1158,167 @@ tmpl_tag_replace(char *tmp, struct mailzip mz, struct rcptinfo *other, char *sen
     //convert str code
     if (dg_str2code_replace(tmptagp, retp, STR_UTF8, STR_JIS) != 0) {
         log(ERR_CHARCODE_CONVERT, "tmpl_tag_replace");
-	free(tmptagp);
-	return(ERROR);
+        free(tmptagp);
+        return(CONVERT_ERROR);
     }
     free(tmptagp);
 
+
     // mime encode header from, rcpt and subject
     ret = encode_tmplheader(retp);
     if (ret == ERROR) {
         log(NOT_ENC_TMPL, "tmpl_tag_replace");
         free(*retp);
-	return(ERROR);
+        return(CONVERT_ERROR);
     }
 
     return(SUCCESS);
 }
 
+/*
+ * tmpl_tag_replace_noconv()
+ *   read new template file and replace tags without converting
+ *
+ * Args:
+ *   struct mailzip   reference data
+ *   struct rcptinfo  reference data
+ *   char *           recipient address
+ *   char **          replaced date
+ *   char *           convert-error template file path
+ *
+ * Return:
+ *   ERROR		-1   error
+ *   SUCCESS		0   success
+ */
+int
+tmpl_tag_replace_noconv(struct mailzip mz, struct rcptinfo *other, 
+                        char *sender, char **retp, char *filepath)
+{
+    int i;
+    char *rcptaddr, *tmpp = NULL, *tmptagp = NULL;
+    int ret = 0, total = 0;
+    int rcptaddr_len = 0;
+    char *name, *tmpf = NULL;
+    int name_len = 0, ret_len = 0, total_len = 0;
+    int tagnum = 0;
+    char *template = NULL;
+
+    struct strtag tmpl_tag[] = {
+        {"SUBJECT", 7, NULL},
+        {"DATE", 4, NULL},
+        {"PASSWORD", 8, NULL},
+        {"RCPTLIST", 8, NULL},
+        {"FILENAME", 8, NULL},
+        {"TOADDR", 6, NULL}
+    };
+    tagnum = sizeof(tmpl_tag) / sizeof(struct strtag);
+
+    // set subject without encoding
+    tmpl_tag[SUBJECT].st_str = (char *)mz.subject;
+
+    // set date
+    tmpl_tag[DATE].st_str = mz.date;
+
+    // set passwd
+    tmpl_tag[PASSWORD].st_str = other->passwd;
+
+    // set toaddr(sender address)
+    tmpl_tag[TOADDR].st_str = sender;
+
+    // rcptaddr total length
+    for (i = 0; (other->rcptlist + i)->rcpt_addr != NULL; i++) {
+        rcptaddr_len = (other->rcptlist + i)->rcpt_addr_len;
+        ret += rcptaddr_len + 1;
+    }
+
+    // allocate memory
+    tmpp = (char *)malloc(ret + 1);
+    if (tmpp == NULL) {
+        log(ERR_MEMORY_ALLOCATE, "tmpl_tag_replace_noconv", "tmpp", strerror(errno));
+        return(ERROR);
+    }
+
+    // reset memory
+    *tmpp = '\0';
+
+    // write memory
+    for (i = 0; (other->rcptlist + i)->rcpt_addr != NULL; i++) {
+        rcptaddr = (other->rcptlist + i)->rcpt_addr;
+        rcptaddr_len = (other->rcptlist + i)->rcpt_addr_len;
+
+        strcat(tmpp, rcptaddr);
+        *(tmpp + total + rcptaddr_len) = '\n';
+        *(tmpp + total + rcptaddr_len + 1) = '\0';
+        total = total + rcptaddr_len + 1;
+    }
+
+    // last '\n' change into '\0'
+    *(tmpp + total - 1) = '\0';
+
+    // store all rcptaddr 
+    tmpl_tag[RCPTLIST].st_str = tmpp;
+
+    //file_name
+    if (mz.namelist != NULL) {
+        for (i = 0; (mz.namelist + i)->attach_name != NULL; i++) {
+            // total length
+            ret_len = ret_len + (mz.namelist + i)->attach_name_len + 1;
+        }
+
+        // allocate memory
+        tmpf = (char *)malloc(ret_len + 1);
+        if (tmpf == NULL) {
+            log(ERR_MEMORY_ALLOCATE, "tmpl_tag_replace_noconv", "tmpf", strerror(errno));
+            free(tmpp);
+
+            return(ERROR);
+        }
+        // reset memory
+        *tmpf = '\0';
+    } else {
+        log(ERR_NULL_FILE_NAME, "tmpl_tag_replace_noconv");    
+        free(tmpp);
+        return(ERROR);
+    }
+
+    // write memory
+    for (i = 0; (mz.namelist + i)->attach_name != NULL; i++) {
+        name = (mz.namelist + i)->attach_name;
+        name_len = (mz.namelist + i)->attach_name_len;
+
+        strcat(tmpf, name);
+        *(tmpf + total_len + name_len) = '\n';
+        *(tmpf + total_len + name_len + 1) = '\0';
+        total_len = total_len + name_len + 1;
+    }
+
+    // last '\n' change into '\0'
+    *(tmpf + total_len - 1) = '\0';
+
+    // store all filename 
+    tmpl_tag[FILENAME].st_str = tmpf;
+
+    // read convert-error template file 
+    if (tmpl_read(&(template), filepath) != 0) {
+        free(tmpp);
+        free(tmpf);
+        return(ERROR);
+    }
+
+    // replace tag
+    tmptagp = str_replace_tag(template, STARTTAG, ENDTAG, tmpl_tag, tagnum);
+    // resouce free
+    free(tmpp);
+    free(tmpf);
+    free(template);
+
+    // str_replace_tag error check
+    if (tmptagp == NULL) {
+        log(ERR_MEMORY_ALLOCATE, "tmpl_tag_replace_noconv", "tmptagp", strerror(errno));
+        return(ERROR);
+    }
+
+    *retp = tmptagp;
+
+    return(SUCCESS);
+}
