@@ -254,32 +254,32 @@ int check_spf(sender_check_arg_t *data)
         return SENDER_CHECK_OK;
 
     case SPF_RESULT_NONE:
-        log(ERR_HARM_SPFNOTFOUND, data->ip, data->message_id,
+        log(NG_HARM_SPFNOTFOUND, data->ip, data->message_id,
             data->envelope_from, data->rcpt_to);
         return SENDER_CHECK_NG;
 
     case SPF_RESULT_NEUTRAL:
-        log(ERR_HARM_SPFNEUTRAL,
+        log(NG_HARM_SPFNEUTRAL,
                 data->ip, data->message_id, data->envelope_from, data->rcpt_to);
         return SENDER_CHECK_NG;
 
     case SPF_RESULT_PERMERROR:
-        log(ERR_HARM_SPFPERM,
+        log(NG_HARM_SPFPERM,
                 data->ip, data->message_id, data->envelope_from, data->rcpt_to);
         return SENDER_CHECK_NG;
 
     case SPF_RESULT_FAIL:
-        log(ERR_HARM_SPFFAIL,
+        log(NG_HARM_SPFFAIL,
                 data->ip, data->message_id, data->envelope_from, data->rcpt_to);
         return SENDER_CHECK_NG;
 
     case SPF_RESULT_SOFTFAIL:
-        log(ERR_HARM_SPFSOFT,
+        log(NG_HARM_SPFSOFT,
                 data->ip, data->message_id, data->envelope_from, data->rcpt_to);
         return SENDER_CHECK_NG;
 
     case SPF_RESULT_INVALID:
-        log(ERR_HARM_SPFINV,
+        log(NG_HARM_SPFINV,
                 data->ip, data->message_id, data->envelope_from, data->rcpt_to);
         return SENDER_CHECK_NG;
 
@@ -326,7 +326,7 @@ int check_senderip(sender_check_arg_t *data)
     }
     if (ret == EAI_NONAME) {
         DEBUGLOG("check_senderip:Error %s\n", gai_strerror(ret));
-        log(ERR_HARM_NAMENOTFOUND, data->ip, data->message_id, 
+        log(NG_HARM_NAMENOTFOUND, data->ip, data->message_id, 
 		data->envelope_from, data->rcpt_to);
         return SENDER_CHECK_NG;
     }
