@@ -13,41 +13,42 @@
  */
 int comp_ipaddr_ipv4(char *domain, struct in_addr *from_addr)
 {
-    int len, ans_num, chk_addr, loop_num;
+    int len, an_num, chk_addr, loop_num;
     u_char nsbuf[EDNS0_MAXPACKET];
     ns_msg msg;
     ns_rr rr;
 
-    /* 渡されたドメインを使ってres_queryでAレコードを引く */
-    len = res_query(domain, ns_c_any, ns_t_a, nsbuf, sizeof(nsbuf));
+    DEBUGLOG("comp_ipaddr_ipv4():domain=[%s]", domain);
 
-    /* res_queryの返り値判断 */
+    /* Query A record */
+    len = res_query(domain, ns_c_any, ns_t_a, nsbuf, sizeof(nsbuf));
     if (len < 0) {
         if (errno == 0) {
+            DEBUGLOG("comp_ipaddr_ipv4(): No A record");
             return SENDER_CHECK_NO_RECORD;
         }
-        DEBUGLOG("check_senderdomain:Error %s\n", strerror(errno));
+        DEBUGLOG("comp_ipaddr_ipv4(): DNS error: %s(%d)", strerror(errno), errno);
         return SENDER_CHECK_ERR;
     }
 
-    /* 結果を分析 */
+    /* Parse result */
     ns_initparse(nsbuf, len, &msg);
     
-    /* 応答数を取得 */
-    ans_num = ns_msg_count(msg, ns_s_an);
+    /* Get number of answer section */
+    an_num = ns_msg_count(msg, ns_s_an);
+    DEBUGLOG("comp_ipaddr_ipv4(): an_num=[%d]\n", an_num);
     
-    /* 応答数だけループして、Aレコードと送信元アドレスを比較 */
-    for (loop_num = 0; loop_num < ans_num; loop_num++) {
-        /* &rrにres_queryの結果を整形して格納 */
+    /* Compare A record and source ip address */
+    for (loop_num = 0; loop_num < an_num; loop_num++) {
         ns_parserr(&msg, ns_s_an, loop_num, &rr);
-
-        /* struct in_addrの構造体へのポインタであるrr.rdataと比較 */
         chk_addr = memcmp(from_addr, rr.rdata, sizeof(struct in_addr));
-
         if (chk_addr == 0) {
+            DEBUGLOG("comp_ipaddr_ipv4(): OK");
             return SENDER_CHECK_OK;
         }
     }
+
+    DEBUGLOG("comp_ipaddr_ipv4(): No match");
     return SENDER_CHECK_NG;
 }
 
@@ -63,41 +64,40 @@ int comp_ipaddr_ipv4(char *domain, struct in_addr *from_addr)
  */
 int comp_ipaddr_ipv6(char *domain, struct in6_addr *from_addr)
 {
-    int len, ans_num, chk_addr, loop_num;
+    int len, an_num, chk_addr, loop_num;
     u_char nsbuf[EDNS0_MAXPACKET];
     ns_msg msg;
     ns_rr rr;
 
-    /* 渡されたドメインを使ってres_queryでAAAAレコードを引く */
+    /* Query AAAA record */
     len = res_query(domain, ns_c_any, ns_t_aaaa, nsbuf, sizeof(nsbuf));
-
-    /* res_queryの返り値判断 */
     if (len < 0) {
         if (errno == 0) {
+            DEBUGLOG("comp_ipaddr_ipv6(): No AAAA record");
             return SENDER_CHECK_NO_RECORD;
         }
-        DEBUGLOG("check_senderdomain:Error %s\n", strerror(errno));
+        DEBUGLOG("comp_ipaddr_ipv6(): DNS error: %s(%d)", strerror(errno), errno);
         return SENDER_CHECK_ERR;
     }
 
-    /* 結果を分析 */
+    /* Parse result */
     ns_initparse(nsbuf, len, &msg);
     
-    /* 応答数を取得 */
-    ans_num = ns_msg_count(msg, ns_s_an);
+    /* Get number of answer section */
+    an_num = ns_msg_count(msg, ns_s_an);
+    DEBUGLOG("comp_ipaddr_ipv6(): an_num=[%d]\n", an_num);
     
-    /* 応答数だけループして、AAAAレコードと送信元アドレスを比較 */
-    for (loop_num = 0; loop_num < ans_num; loop_num++) {
-        /* &rrにres_queryの結果を整形して格納 */
+    /* Compare AAAA record and source ip address */
+    for (loop_num = 0; loop_num < an_num; loop_num++) {
         ns_parserr(&msg, ns_s_an, loop_num, &rr);
-
-        /* struct in6_addrの構造体へのポインタであるrr.rdataと比較 */
         chk_addr = memcmp(from_addr, rr.rdata, sizeof(struct in6_addr));
-
         if (chk_addr == 0) {
+            DEBUGLOG("comp_ipaddr_ipv6(): OK");
             return SENDER_CHECK_OK;
         }
     }
+
+    DEBUGLOG("comp_ipaddr_ipv6(): No match");
     return SENDER_CHECK_NG;
 }
 
@@ -137,74 +137,94 @@ int comp_ipaddr(char *domain, sender_check_arg_t *data)
  */
 int comp_mx(char *domain, sender_check_arg_t *data)
 {
-    int len, len_dom, ans_num, loop_num, res_mx;
+    int len, len_dom, an_num, qd_num, loop_num, res_mx;
     u_char nsbuf[EDNS0_MAXPACKET];
     u_char *conts;
     ns_msg msg;
     char dom[NS_MAXDNAME];
 
-    /* 渡されたドメインを使ってres_queryでMXレコードを引く */
+    /* Query mx record */
     len = res_query(domain, ns_c_any, ns_t_mx, nsbuf, sizeof(nsbuf));
-
-    /* res_queryの返り値判断 */
     if (len < 0) {
         if (errno == 0) {
+            DEBUGLOG("comp_mx(): No mx record");
             return SENDER_CHECK_NG;
         }
-        DEBUGLOG("check_senderdomain:Error %s\n", strerror(errno));
+        DEBUGLOG("comp_mx(): DNS error: %s(%d)", strerror(errno), errno);
         return SENDER_CHECK_ERR;
     }
 
-    /* 結果を分析 */
+    /* Parse result */
     ns_initparse(nsbuf, len, &msg);
 
-    /* 応答数を取得 */
-    ans_num = ns_msg_count(msg, ns_s_an);
+    /* Get number of question section */
+    qd_num = ns_msg_count(msg, ns_s_qd);
+    DEBUGLOG("comp_mx(): qd_num=[%d]", qd_num);
 
-    /* 応答のヘッダ以降をcontsへ格納 */
+    /* Get number of answer section */
+    an_num = ns_msg_count(msg, ns_s_an);
+    DEBUGLOG("comp_mx(): an_num=[%d]", an_num);
+
+    /* Skip header */
     conts = nsbuf + sizeof(HEADER);
 
-    /* 問い合わせ部の圧縮されたドメインを展開 */
-    len_dom = dn_expand(nsbuf, nsbuf + len, conts, dom, sizeof(dom));
-
-    if (len_dom < 0) {
-        return SENDER_CHECK_ERR;
-    }
-
-    /* 問い合わせ部のドメイン分contsの参照先を進める */
-    conts += len_dom;
-
-    /* 不要な分の読み捨て */
-    conts += NS_INT16SZ * 2;
-    
-    /* 応答数だけループして、Aレコードと送信元アドレスを比較 */
-    for (loop_num = 0; loop_num < ans_num; loop_num++) {
-        /* 回答部の圧縮された問い合わせドメインを展開 */
+    /*
+     * Parse Query section
+     */
+    for (loop_num = 0; loop_num < qd_num; loop_num++) {
+        /* Get domain name */
         len_dom = dn_expand(nsbuf, nsbuf + len, conts, dom, sizeof(dom));
-
         if (len_dom < 0) {
+            DEBUGLOG("comp_mx(): dn_expand() error 0");
             return SENDER_CHECK_ERR;
         }
+        DEBUGLOG("comp_mx(1): len_dom=[%d],dom=[%s]", len_dom, dom);
 
+        /* Skip Name */
         conts += len_dom;
 
-        /* 不要な分の読み捨て */
-        conts += NS_INT16SZ * 4 + NS_INT32SZ;
-
-        /* 回答部の圧縮された回答ドメインを展開 */
+        /* Skip Type(2bytes),Class(2bytes) */
+        conts += NS_INT16SZ * 2;
+    }
+    
+    /*
+     * Parse Answer section
+     */
+    for (loop_num = 0; loop_num < an_num; loop_num++) {
+        /* Get domain name */
         len_dom = dn_expand(nsbuf, nsbuf + len, conts, dom, sizeof(dom));
-
         if (len_dom < 0) {
+            DEBUGLOG("comp_mx(): dn_expand() error 1");
             return SENDER_CHECK_ERR;
         }
+        DEBUGLOG("comp_mx(2): len_dom=[%d],dom=[%s]", len_dom, dom);
 
-        /* 取得できたMXレコードをcomp_ipaddrへ渡す */
+        /* Skip Name */
+        conts += len_dom;
+
+        /*
+         * Skip Type(2bytes),Class(2bytes),TTL(4bytes),
+         *      Length(2bytes),Preference(2bytes)
+         */
+        conts += NS_INT16SZ * 4 + NS_INT32SZ;
+
+        /* Get MX record */
+        len_dom = dn_expand(nsbuf, nsbuf + len, conts, dom, sizeof(dom));
+        if (len_dom < 0) {
+            DEBUGLOG("comp_mx(): dn_expand() error 2");
+            return SENDER_CHECK_ERR;
+        }
+        DEBUGLOG("comp_mx(3): len_dom=[%d],dom=[%s]", len_dom, dom);
+
+        /* Skip MX */
+        conts += len_dom;
+
+        /* Compare mx record and source ip address */
         res_mx = comp_ipaddr(dom, data);
         switch (res_mx) {
             case SENDER_CHECK_ERR:
-                return SENDER_CHECK_ERR;
             case SENDER_CHECK_OK:
-                return SENDER_CHECK_OK;
+                return res_mx;
         }
     }
     return SENDER_CHECK_NG;
