@@ -874,7 +874,7 @@ parse_mail(struct mailinfo *minfo, struct config *cfg, struct mailzip *mz)
     ct_object = g_mime_object_get_content_type(object);
 
     /* default policy set */
-    if ((cfg->cf_alternativepartencrypt[0] == 'N') || (cfg->cf_alternativepartencrypt[0] == 'n')) {
+    if (ismode_delete || (cfg->cf_alternativepartencrypt[0] == 'N') || (cfg->cf_alternativepartencrypt[0] == 'n')) {
         if ((strncmp(ct_object->type, CONTENT_T_MULTIPART, LEN_CONTENT_T_MULTIPART) == 0) && 
             ((strncmp(ct_object->subtype, CONTENT_SUBT_RELATED, LEN_CONTENT_SUBT_RELATED) == 0) ||
              (strncmp(ct_object->subtype, CONTENT_SUBT_ALTERNATIVE, LEN_CONTENT_SUBT_ALTERNATIVE) == 0))) {
